/** @typedef {import('../database.class.js') Database} */

const { is } = require('@creanet/js-type');

class Query {
  /**
   * Creates an instance of Query.
   *
   * @param {Database} db
   */
  constructor(db) {
    this._db = db._db;

    this.data = [];

    this.executed = false;
    this.success = null;

    this.rows = null;
    this.response = null;

    this.err = null;

    this._onsuccess = null;
  }

  /**
   * Returns the PostgreSQL query
   *
   * @type String
   * @readonly
   */
  get query() {
    return null;
  }

  /**
   * Returns `true` if Query can be executed, `false` otherwise
   * - Note, that this function DOES NOT check syntax
   *
   * @readonly
   */
  get canExecute() {
    return is.not.emptyString(this.query);
  }

  /**
   * Sets the onsuccess callback
   *
   * @param {Function} onsuccess
   * @returns Query
   */
  onsuccess(onsuccess) {
    this._onsuccess = onsuccess;
    return this;
  }

  /**
   * Executes a generic query
   * - returns `true` if successful; `false` otherwise
   *
   * @returns {Promise.<boolean>} success
   */
  async execute() {
    if (!this.canExecute) throw new Error('This query cannot be executed yet');

    return new Promise(resolve => {
      this._db.query(this.query, this.data, (err, res) => {
        this.executed = true;
        this.response = res;

        if (err) {
          this.success = false;
          this.err = err;

          resolve(false);
        } else {
          this.rows = res.rows;
          this.success = true;

          if (this._onsuccess instanceof Function) {
            this._onsuccess();
          }

          resolve(true);
        }
      });
    });
  }
}

module.exports = Query;
