/** @typedef {import("./query.class")} Query */
/** @typedef {import("./query.generic.class")} GenericQuery */
/** @typedef {import("../database.class")} Database */

class Tape {
  /**
   * Creates an instance of Tape.
   * @param {Database} db
   */
  constructor(db) {
    this._db = db;
    /** @type {Array.<Query>} */
    this.commands = [];
  }

  /**
   * Records a new command to the tape
   * @param {Query} query
   */
  add(query) {
    this.commands.push(query);
    return this;
  }

  /**
   * Builds the query
   * @returns {GenericQuery} query
   */
  build() {
    return this._db.query(this.commands.map(item => item.query).join(';\n'));
  }
}

module.exports = Tape;
