const { is, force } = require('@creanet/js-type');

const ColumnsMixin = C =>
  class ColumnsMixin extends C {
    constructor() {
      super(...arguments);
      this._columns = null;
    }

    get columnsSQL() {
      return this._columns.join(',');
    }

    /**
     * Sets the names of columns. Valid values are:
     * - `'*'` - select all colums
     * - `{string}` Name of single column
     * - `{array.<string>}` Array with column names
     *
     * @param {string|string[]} columns
     */
    columns(columns) {
      columns = force.array(columns);

      if (is.not.array(columns, 'string')) {
        throw TypeError('columns is of invalid type');
      }

      this._columns = columns;

      return this;
    }
  };

module.exports = ColumnsMixin;
