const { is } = require('@creanet/js-type');

const LimitMixin = C =>
  class LimitMixin extends C {
    constructor() {
      super(...arguments);
      this._limit = null;
    }

    get limitSQL() {
      if (is.null(this._limit)) {
        return '';
      }

      return `LIMIT ${this._limit}`;
    }

    /**
     * Sets the limit of query. Valid values are:
     * - `{number}` - maximal number of rows
     *
     * @param {number} limit
     */
    limit(limit) {
      if (is.not.numeric(limit)) {
        throw TypeError('limit is of invalid type');
      }

      this._limit = limit;

      return this;
    }
  };

module.exports = LimitMixin;
