const { is, force } = require('@creanet/js-type');

const ReturningMixin = (C) =>
  class ReturningMixin extends C {
    constructor() {
      super(...arguments);
      this._returning = null;
    }

    get returningSQL() {
      return this._returning.join(',');
    }

    /**
     * Sets the names of returning. Valid values are:
     * - `'*'` - select all colums
     * - `{string}` Name of single column
     * - `{array.<string>}` Array with column names
     *
     * @param {string|string[]} returning
     */
    returning(returning) {
      returning = force.array(returning);

      if (is.not.array(returning, 'string')) {
        throw TypeError('returning is of invalid type');
      }

      this._returning = returning;

      return this;
    }
  };

module.exports = ReturningMixin;
