const { is, force } = require('@creanet/js-type');

const ValuesMixin = C =>
  class ValuesMixin extends C {
    constructor() {
      super(...arguments);
      this._values = null;
    }

    get valuesSQL() {
      const head = Object.keys(this._values[0]).join(',');

      const body = this._values
        .map(record => `(${Object.values(record).map(value => `'${value}'`)})`)
        .join(', ');

      return `(${head}) VALUES ${body}`;
    }

    /**
     * Sets the values of query. Valid values are:
     * - `{Object}` - one record with key:value pairs
     * - `{Array<Object>} - multiple records
     *
     * @param {Object|Array<Object>} values
     */
    values(values) {
      values = force.array(values);

      if (is.not.array(values, 'object')) {
        throw new TypeError('values is of invalid type');
      }

      this._values = values;

      return this;
    }
  };

module.exports = ValuesMixin;
