const { is } = require('@creanet/js-type');

const WhereMixin = C =>
  class WhereMixin extends C {
    constructor() {
      super(...arguments);
      this._where = null;
    }

    get whereSQL() {
      if (is.null(this._where)) {
        return '';
      }

      return `WHERE ${this._where}`;
    }

    /**
     * Sets the where of query. Valid values are:
     * - `{string}` - SQL expression
     *
     * @param {Array<Object>} where
     */
    where(where) {
      if (is.not(where, ['string', 'object']))
        throw new TypeError('where is of invalid type');

      if (is.object(where)) {
        this._where = Object.entries(where)
          .map(([key, value]) => `${key}='${value}'`)
          .join(' AND ');
      } else {
        this._where = where;
      }

      return this;
    }
  };

module.exports = WhereMixin;
