require('dotenv').config();
const DB = require('../index');

const db = new DB({
  host: process.env.DB_HOST,
  port: process.env.DB_PORT,
  database: process.env.DB_NAME,
  user: process.env.DB_USER,
  password: process.env.DB_PASS
});

const createTable = async () => {
  const query = db.query(`
    CREATE TABLE IF NOT EXISTS lorem (
      "foo" TEXT,
      "bar" INTEGER
    );
  `);

  if (await query.execute()) {
    console.log('Table created');
  } else {
    console.log(query.err);
  }
};

const select = async () => {
  console.log('SELECT');
  const select = db.select('lorem').columns('*');

  console.log(select.query);
  if (await select.execute()) {
    console.log(select.rows);
  } else {
    console.log(select.err);
  }
};

const insert = async () => {
  console.log('INSERT');
  const insert = db.insert('lorem').values([
    { foo: 'Ahoj', bar: 12 },
    { foo: 'Čau', bar: Math.floor(Math.random() * 100) }
  ]);
  if (await insert.execute()) {
    console.log(insert.rows);
  } else {
    console.log(insert.err);
  }
};

const del = async () => {
  console.log('DELETE');
  const del = db.delete('lorem').where({ bar: 12 });

  if (await del.execute()) {
    console.log(del.rows);
  } else {
    console.log(del.err);
  }
};

const update = async () => {
  console.log(await db.begin());

  console.log('UPDATE');
  const update = db
    .update('lorem')
    .set({ foo: 'Updated Čau', bar: 420 })
    .where({ id: 4 });

  console.log(update.query);
  if (await update.execute()) {
    console.log(update.rows);
  } else {
    console.log(update.err);
  }

  console.log(await db.commit());
};

(async () => {
  await createTable();
  await insert();
  await select();

  // await update();
  // await select();

  // const query = db
  //   .tape()
  //   .add(db.begin())
  //   .add(
  //     db
  //       .update('lorem')
  //       .set({ foo: 'Updated Čau', bar: 420 })
  //       .where({ id: 4 })
  //   )
  //   .add(
  //     db.insert('lorem').values([
  //       { foo: 'Ahoj', bar: 12 },
  //       { foo: 'Čau', bar: 52 }
  //     ])
  //   )
  //   .add(db.select('lorem').columns('*'))
  //   .add(db.commit())
  //   .build();

  // if (await query.execute()) {
  //   console.log(query.response);
  // } else {
  //   console.log(query.err);
  // }

  process.exit();
})();

// const select = db
//   .select()
//   .columns('*')
//   .limit(5)
//   .offset(5);
